@@ -59,8 +59,8 @@ WSDL_4D = CONFIG['4D']['wsdl']
 PAYLOAD = {
     'root': {
         'header': {
-            'version': '1',
-            'param1': None,
+            'version': "1",
+            'param1': "ussd_buy_recharge",
             'ident': CONFIG['4D']['ident'],
             'psw': CONFIG['4D']['pwd'],
         },
