@@ -88,7 +88,13 @@ class IzyTV(object):
                     else:
                         LOGS.logger.info(response)
                 elif data["operator"] == "orange-izytv":
-                    self.orange_izy_tv(transId, data)
+                    try:
+                        self.orange_izy_tv(transId, data)
+                    except Exception:
+                        LOGS.logger.error("_____________ERREURRRRRRRRRR_____________________________") 
+                        LOGS.logger.error(transId) 
+                        LOGS.logger.error("_________________________________________________________") 
+                        
                 elif data["operator"] == "airtel-izytv":
                     self.airtel_izytv(transId, data)
                 else:
